<?php

namespace Drupal\concord_cookie_consent\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Configuration form for Concord Cookie Consent settings.
 */
class BodyForm extends ConfigFormBase {

  const CONFIG_NAME = 'concord_cookie_consent.settings';
  const ENABLE_KEY = 'enable';
  const SCRIPTS_KEY = 'scripts';
  const UUID_PATTERN = '/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}/';
  const CONCORD_URL_PATTERN = '/^https:\/\/api\.concord\.tech\/site-v1\/[0-9a-f-]+\/site-client$/';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'concord_cookie_consent_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [self::CONFIG_NAME];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, Request $request = NULL) {
    $config = $this->config(self::CONFIG_NAME);

    $form['settings'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Concord Settings'),
    ];

    $form['general'] = [
      '#type' => 'details',
      '#title' => $this->t('General Settings'),
      '#group' => 'settings',
      '#open' => TRUE,
    ];

    $form['general']['enable'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Concord Cookie Consent'),
      '#description' => $this->t('Enable or disable Concord functionality.'),
      '#default_value' => $config->get(self::ENABLE_KEY) ?? FALSE,
    ];

    $form['script_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Script Configuration'),
      '#group' => 'settings',
      '#open' => TRUE,
    ];

    $form['script_settings']['scripts'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Concord Script'),
      '#description' => $this->t('Example format: <code>&lt;script type="text/javascript" src="https://api.concord.tech/site-v1/YOUR-PROJECT-ID/site-client"&gt;&lt;/script&gt;</code>'),
      '#default_value' => $config->get(self::SCRIPTS_KEY) ?? '',
      '#rows' => 3,
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    
    $script = trim($form_state->getValue('scripts'));

    // Validate script tag structure
    if (!preg_match('/<script[^>]*>[^<]*<\/script>/', $script)) {
      $form_state->setErrorByName('scripts', $this->t('Invalid script format. Please use complete script tag.'));
      return;
    }

    // Extract src attribute
    if (preg_match('/src=[\'"](.*?)[\'"]/i', $script, $matches)) {
      $src = $matches[1];
      
      // Validate Concord URL format
      if (!preg_match(self::CONCORD_URL_PATTERN, $src)) {
        $form_state->setErrorByName('scripts', $this->t('Invalid Concord URL format.'));
      }

      // Validate UUID in URL
      if (!preg_match(self::UUID_PATTERN, $src)) {
        $form_state->setErrorByName('scripts', $this->t('Invalid UUID in Concord URL.'));
      }
    } else {
      $form_state->setErrorByName('scripts', $this->t('Missing src attribute in script tag.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(self::CONFIG_NAME)
      ->set(self::SCRIPTS_KEY, trim($form_state->getValue('scripts')))
      ->set(self::ENABLE_KEY, (bool) $form_state->getValue('enable'))
      ->save();

    parent::submitForm($form, $form_state);
    $this->messenger()->addStatus($this->t('Concord configuration has been updated.'));
  }
}